import { AngularEnvOptions, BrowserOptions, DevServerOptions } from '@teambit/angular-common';
import { AppContext } from '@teambit/application';
import { Bundler, BundlerContext, DevServer, DevServerContext } from '@teambit/bundler';
import { AsyncEnvHandler, EnvHandler } from '@teambit/envs';
import { EnvPreviewConfig, Preview } from '@teambit/preview';
import { WebpackConfigTransformer, WebpackConfigWithDevServer } from '@teambit/webpack';
import { Configuration } from 'webpack';
import 'webpack-dev-server';
export declare type DevServerProvider = (context: DevServerContext | (DevServerContext & AppContext), transformers?: WebpackConfigTransformer[], angularOptions?: Partial<BrowserOptions & DevServerOptions>, webpackOptions?: Partial<WebpackConfigWithDevServer | Configuration>, sourceRoot?: string) => AsyncEnvHandler<DevServer>;
export declare type BundlerProvider = (context: BundlerContext | (BundlerContext & AppContext), transformers?: WebpackConfigTransformer[], angularOptions?: Partial<BrowserOptions & DevServerOptions>, webpackOptions?: Partial<WebpackConfigWithDevServer | Configuration>, sourceRoot?: string) => AsyncEnvHandler<Bundler>;
interface AngularPreviewOptions {
    /**
     * Name of the angular preview.
     */
    name?: string;
    /**
     * Configuration for the preview.
     */
    previewConfig?: EnvPreviewConfig;
    /**
     * Deps that will be bundled with the env template and will be configured as externals for the component bundle.
     * These dependencies will be available in the preview as singletons.
     */
    hostDependencies?: string[];
    /**
     * Bundler to be used for the preview.
     */
    bundlerProvider: BundlerProvider;
    /**
     * Dev server to use for preview.
     */
    devServerProvider: DevServerProvider;
    /**
     * Angular env options
     */
    ngEnvOptions: AngularEnvOptions;
    /**
     * Override the default Angular docs template path
     */
    docsTemplatePath?: string;
    /**
     * Override the default Angular mount path
     */
    mounterPath?: string;
}
export declare class AngularPreview implements Preview {
    readonly name: string;
    private ngEnvOptions;
    private devServerProvider;
    private bundlerProvider;
    private docsTemplatePath;
    private mounterPath;
    private previewConfig;
    private hostDependencies?;
    private constructor();
    getDevServer(context: DevServerContext, transformers?: WebpackConfigTransformer[], angularOptions?: Partial<BrowserOptions & DevServerOptions>, webpackOptions?: Partial<WebpackConfigWithDevServer | Configuration>, sourceRoot?: string): AsyncEnvHandler<DevServer>;
    getDevEnvId(): string;
    getBundler(context: BundlerContext): AsyncEnvHandler<Bundler>;
    getHostDependencies(): string[];
    getMounter(): string;
    getDocsTemplate(): string;
    getPreviewConfig(): EnvPreviewConfig & {
        isScaling?: boolean;
    };
    static from(options: AngularPreviewOptions): EnvHandler<Preview>;
}
export {};
