"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AngularPreview = void 0;
const object_hash_1 = __importDefault(require("object-hash"));
// Make sure bit recognizes the dependencies
require("webpack-dev-server");
class AngularPreview {
    constructor(name, ngEnvOptions, devServerProvider, bundlerProvider, docsTemplatePath = require.resolve('./docs'), mounterPath = require.resolve('./mounter'), previewConfig = {}, hostDependencies) {
        this.name = name;
        this.ngEnvOptions = ngEnvOptions;
        this.devServerProvider = devServerProvider;
        this.bundlerProvider = bundlerProvider;
        this.docsTemplatePath = docsTemplatePath;
        this.mounterPath = mounterPath;
        this.previewConfig = previewConfig;
        this.hostDependencies = hostDependencies;
    }
    getDevServer(context, transformers, angularOptions, webpackOptions, sourceRoot) {
        return this.devServerProvider(context, transformers, angularOptions, webpackOptions, sourceRoot);
    }
    getDevEnvId() {
        const objToHash = {
            webpack: this.ngEnvOptions.webpackModulePath,
            webpackDevServer: this.ngEnvOptions.webpackDevServerModulePath,
        };
        return (0, object_hash_1.default)(objToHash);
    }
    getBundler(context) {
        return this.bundlerProvider(context);
    }
    getHostDependencies() {
        return (this.hostDependencies || [
            '@teambit/mdx.ui.mdx-scope-context',
            '@mdx-js/react',
            'react',
            'react-dom',
        ]);
    }
    getMounter() {
        return this.mounterPath;
    }
    getDocsTemplate() {
        return this.docsTemplatePath;
    }
    getPreviewConfig() {
        return Object.assign({ strategyName: 'env' }, this.previewConfig);
    }
    static from(options) {
        const name = options.name || 'angular-preview';
        return () => {
            return new AngularPreview(name, options.ngEnvOptions, options.devServerProvider, options.bundlerProvider, options.docsTemplatePath, options.mounterPath, options.previewConfig, options.hostDependencies);
        };
    }
}
exports.AngularPreview = AngularPreview;
//# sourceMappingURL=angular-preview.js.map